Class: Aws::IoTThingsGraph::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTThingsGraph::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotthingsgraph/client.rb,
sig/client.rbs
Overview
An API client for IoTThingsGraph. To construct a client, you need to configure a :region and :credentials.
client = Aws::IoTThingsGraph::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateEntityToThingResponseSuccess, _CreateFlowTemplateResponseSuccess, _CreateSystemInstanceResponseSuccess, _CreateSystemTemplateResponseSuccess, _DeleteFlowTemplateResponseSuccess, _DeleteNamespaceResponseSuccess, _DeleteSystemInstanceResponseSuccess, _DeleteSystemTemplateResponseSuccess, _DeploySystemInstanceResponseSuccess, _DeprecateFlowTemplateResponseSuccess, _DeprecateSystemTemplateResponseSuccess, _DescribeNamespaceResponseSuccess, _DissociateEntityFromThingResponseSuccess, _GetEntitiesResponseSuccess, _GetFlowTemplateResponseSuccess, _GetFlowTemplateRevisionsResponseSuccess, _GetNamespaceDeletionStatusResponseSuccess, _GetSystemInstanceResponseSuccess, _GetSystemTemplateResponseSuccess, _GetSystemTemplateRevisionsResponseSuccess, _GetUploadStatusResponseSuccess, _ListFlowExecutionMessagesResponseSuccess, _ListTagsForResourceResponseSuccess, _SearchEntitiesResponseSuccess, _SearchFlowExecutionsResponseSuccess, _SearchFlowTemplatesResponseSuccess, _SearchSystemInstancesResponseSuccess, _SearchSystemTemplatesResponseSuccess, _SearchThingsResponseSuccess, _TagResourceResponseSuccess, _UndeploySystemInstanceResponseSuccess, _UntagResourceResponseSuccess, _UpdateFlowTemplateResponseSuccess, _UpdateSystemTemplateResponseSuccess, _UploadEntityDefinitionsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_entity_to_thing(params = {}) ⇒ Struct
Associates a device with a concrete thing that is in the user's registry.
-
#create_flow_template(params = {}) ⇒ Types::CreateFlowTemplateResponse
Creates a workflow template.
-
#create_system_instance(params = {}) ⇒ Types::CreateSystemInstanceResponse
Creates a system instance.
-
#create_system_template(params = {}) ⇒ Types::CreateSystemTemplateResponse
Creates a system.
-
#delete_flow_template(params = {}) ⇒ Struct
Deletes a workflow.
-
#delete_namespace(params = {}) ⇒ Types::DeleteNamespaceResponse
Deletes the specified namespace.
-
#delete_system_instance(params = {}) ⇒ Struct
Deletes a system instance.
-
#delete_system_template(params = {}) ⇒ Struct
Deletes a system.
-
#deploy_system_instance(params = {}) ⇒ Types::DeploySystemInstanceResponse
Greengrass and Cloud Deployments.
-
#deprecate_flow_template(params = {}) ⇒ Struct
Deprecates the specified workflow.
-
#deprecate_system_template(params = {}) ⇒ Struct
Deprecates the specified system.
-
#describe_namespace(params = {}) ⇒ Types::DescribeNamespaceResponse
Gets the latest version of the user's namespace and the public version that it is tracking.
-
#dissociate_entity_from_thing(params = {}) ⇒ Struct
Dissociates a device entity from a concrete thing.
-
#get_entities(params = {}) ⇒ Types::GetEntitiesResponse
Gets definitions of the specified entities.
-
#get_flow_template(params = {}) ⇒ Types::GetFlowTemplateResponse
Gets the latest version of the
DefinitionDocumentandFlowTemplateSummaryfor the specified workflow. -
#get_flow_template_revisions(params = {}) ⇒ Types::GetFlowTemplateRevisionsResponse
Gets revisions of the specified workflow.
-
#get_namespace_deletion_status(params = {}) ⇒ Types::GetNamespaceDeletionStatusResponse
Gets the status of a namespace deletion task.
-
#get_system_instance(params = {}) ⇒ Types::GetSystemInstanceResponse
Gets a system instance.
-
#get_system_template(params = {}) ⇒ Types::GetSystemTemplateResponse
Gets a system.
-
#get_system_template_revisions(params = {}) ⇒ Types::GetSystemTemplateRevisionsResponse
Gets revisions made to the specified system template.
-
#get_upload_status(params = {}) ⇒ Types::GetUploadStatusResponse
Gets the status of the specified upload.
-
#list_flow_execution_messages(params = {}) ⇒ Types::ListFlowExecutionMessagesResponse
Returns a list of objects that contain information about events in a flow execution.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags on an AWS IoT Things Graph resource.
-
#search_entities(params = {}) ⇒ Types::SearchEntitiesResponse
Searches for entities of the specified type.
-
#search_flow_executions(params = {}) ⇒ Types::SearchFlowExecutionsResponse
Searches for AWS IoT Things Graph workflow execution instances.
-
#search_flow_templates(params = {}) ⇒ Types::SearchFlowTemplatesResponse
Searches for summary information about workflows.
-
#search_system_instances(params = {}) ⇒ Types::SearchSystemInstancesResponse
Searches for system instances in the user's account.
-
#search_system_templates(params = {}) ⇒ Types::SearchSystemTemplatesResponse
Searches for summary information about systems in the user's account.
-
#search_things(params = {}) ⇒ Types::SearchThingsResponse
Searches for things associated with the specified entity.
-
#tag_resource(params = {}) ⇒ Struct
Creates a tag for the specified resource.
-
#undeploy_system_instance(params = {}) ⇒ Types::UndeploySystemInstanceResponse
Removes a system instance from its target (Cloud or Greengrass).
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from the specified resource.
-
#update_flow_template(params = {}) ⇒ Types::UpdateFlowTemplateResponse
Updates the specified workflow.
-
#update_system_template(params = {}) ⇒ Types::UpdateSystemTemplateResponse
Updates the specified system.
-
#upload_entity_definitions(params = {}) ⇒ Types::UploadEntityDefinitionsResponse
Asynchronously uploads one or more entity definitions to the user's namespace.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-iotthingsgraph/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2063 2064 2065 |
# File 'lib/aws-sdk-iotthingsgraph/client.rb', line 2063 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2066 2067 2068 |
# File 'lib/aws-sdk-iotthingsgraph/client.rb', line 2066 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_entity_to_thing(params = {}) ⇒ Struct
Associates a device with a concrete thing that is in the user's registry.
A thing can be associated with only one device at a time. If you associate a thing with a new device id, its previous association will be removed.
86 |
# File 'sig/client.rbs', line 86
def associate_entity_to_thing: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 |
# File 'lib/aws-sdk-iotthingsgraph/client.rb', line 2036 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTThingsGraph') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iotthingsgraph' context[:gem_version] = '1.73.0' Seahorse::Client::Request.new(handlers, context) end |
#create_flow_template(params = {}) ⇒ Types::CreateFlowTemplateResponse
Creates a workflow template. Workflows can be created only in the user's namespace. (The public namespace contains only entities.) The workflow can contain only entities in the specified namespace. The workflow is validated against the entities in the latest version of the user's namespace unless another namespace version is specified in the request.
98 |
# File 'sig/client.rbs', line 98
def create_flow_template: (
|
#create_system_instance(params = {}) ⇒ Types::CreateSystemInstanceResponse
Creates a system instance.
This action validates the system instance, prepares the
deployment-related resources. For Greengrass deployments, it updates
the Greengrass group that is specified by the greengrassGroupName
parameter. It also adds a file to the S3 bucket specified by the
s3BucketName parameter. You need to call DeploySystemInstance
after running this action.
For Greengrass deployments, since this action modifies and adds resources to a Greengrass group and an S3 bucket on the caller's behalf, the calling identity must have write permissions to both the specified Greengrass group and S3 bucket. Otherwise, the call will fail with an authorization error.
For cloud deployments, this action requires a flowActionsRoleArn
value. This is an IAM role that has permissions to access AWS
services, such as AWS Lambda and AWS IoT, that the flow uses when it
executes.
If the definition document doesn't specify a version of the user's namespace, the latest version will be used by default.
112 |
# File 'sig/client.rbs', line 112
def create_system_instance: (
|
#create_system_template(params = {}) ⇒ Types::CreateSystemTemplateResponse
Creates a system. The system is validated against the entities in the latest version of the user's namespace unless another namespace version is specified in the request.
139 |
# File 'sig/client.rbs', line 139
def create_system_template: (
|
#delete_flow_template(params = {}) ⇒ Struct
Deletes a workflow. Any new system or deployment that contains this workflow will fail to update or deploy. Existing deployments that contain the workflow will continue to run (since they use a snapshot of the workflow taken at the time of deployment).
152 |
# File 'sig/client.rbs', line 152
def delete_flow_template: (
|
#delete_namespace(params = {}) ⇒ Types::DeleteNamespaceResponse
Deletes the specified namespace. This action deletes all of the entities in the namespace. Delete the systems and flows that use entities in the namespace before performing this action. This action takes no request parameters.
163 |
# File 'sig/client.rbs', line 163
def delete_namespace: (
|
#delete_system_instance(params = {}) ⇒ Struct
Deletes a system instance. Only system instances that have never been deployed, or that have been undeployed can be deleted.
Users can create a new system instance that has the same ID as a deleted system instance.
171 |
# File 'sig/client.rbs', line 171
def delete_system_instance: (
|
#delete_system_template(params = {}) ⇒ Struct
Deletes a system. New deployments can't contain the system after its deletion. Existing deployments that contain the system will continue to work because they use a snapshot of the system that is taken when it is deployed.
180 |
# File 'sig/client.rbs', line 180
def delete_system_template: (
|
#deploy_system_instance(params = {}) ⇒ Types::DeploySystemInstanceResponse
Greengrass and Cloud Deployments
Deploys the system instance to the target specified in
CreateSystemInstance.
Greengrass Deployments
If the system or any workflows and entities have been updated before this action is called, then the deployment will create a new Amazon Simple Storage Service resource file and then deploy it.
Since this action creates a Greengrass deployment on the caller's behalf, the calling identity must have write permissions to the specified Greengrass group. Otherwise, the call will fail with an authorization error.
For information about the artifacts that get added to your Greengrass core device when you use this API, see AWS IoT Things Graph and AWS IoT Greengrass.
191 |
# File 'sig/client.rbs', line 191
def deploy_system_instance: (
|
#deprecate_flow_template(params = {}) ⇒ Struct
Deprecates the specified workflow. This action marks the workflow for deletion. Deprecated flows can't be deployed, but existing deployments will continue to run.
200 |
# File 'sig/client.rbs', line 200
def deprecate_flow_template: (
|
#deprecate_system_template(params = {}) ⇒ Struct
Deprecates the specified system.
209 |
# File 'sig/client.rbs', line 209
def deprecate_system_template: (
|
#describe_namespace(params = {}) ⇒ Types::DescribeNamespaceResponse
Gets the latest version of the user's namespace and the public version that it is tracking.
223 |
# File 'sig/client.rbs', line 223
def describe_namespace: (
|
#dissociate_entity_from_thing(params = {}) ⇒ Struct
Dissociates a device entity from a concrete thing. The action takes only the type of the entity that you need to dissociate because only one entity of a particular type can be associated with a thing.
232 |
# File 'sig/client.rbs', line 232
def dissociate_entity_from_thing: (
|
#get_entities(params = {}) ⇒ Types::GetEntitiesResponse
Gets definitions of the specified entities. Uses the latest version of the user's namespace by default. This API returns the following TDM entities.
-
Properties
-
States
-
Events
-
Actions
-
Capabilities
-
Mappings
-
Devices
-
Device Models
-
Services
This action doesn't return definitions for systems, flows, and deployments.
243 |
# File 'sig/client.rbs', line 243
def get_entities: (
|
#get_flow_template(params = {}) ⇒ Types::GetFlowTemplateResponse
Gets the latest version of the DefinitionDocument and
FlowTemplateSummary for the specified workflow.
254 |
# File 'sig/client.rbs', line 254
def get_flow_template: (
|
#get_flow_template_revisions(params = {}) ⇒ Types::GetFlowTemplateRevisionsResponse
Gets revisions of the specified workflow. Only the last 100 revisions are stored. If the workflow has been deprecated, this action will return revisions that occurred before the deprecation. This action won't work for workflows that have been deleted.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
266 |
# File 'sig/client.rbs', line 266
def get_flow_template_revisions: (
|
#get_namespace_deletion_status(params = {}) ⇒ Types::GetNamespaceDeletionStatusResponse
Gets the status of a namespace deletion task.
282 |
# File 'sig/client.rbs', line 282
def get_namespace_deletion_status: (
|
#get_system_instance(params = {}) ⇒ Types::GetSystemInstanceResponse
Gets a system instance.
291 |
# File 'sig/client.rbs', line 291
def get_system_instance: (
|
#get_system_template(params = {}) ⇒ Types::GetSystemTemplateResponse
Gets a system.
301 |
# File 'sig/client.rbs', line 301
def get_system_template: (
|
#get_system_template_revisions(params = {}) ⇒ Types::GetSystemTemplateRevisionsResponse
Gets revisions made to the specified system template. Only the previous 100 revisions are stored. If the system has been deprecated, this action will return the revisions that occurred before its deprecation. This action won't work with systems that have been deleted.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
313 |
# File 'sig/client.rbs', line 313
def get_system_template_revisions: (
|
#get_upload_status(params = {}) ⇒ Types::GetUploadStatusResponse
Gets the status of the specified upload.
331 |
# File 'sig/client.rbs', line 331
def get_upload_status: (
|
#list_flow_execution_messages(params = {}) ⇒ Types::ListFlowExecutionMessagesResponse
Returns a list of objects that contain information about events in a flow execution.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
342 |
# File 'sig/client.rbs', line 342
def list_flow_execution_messages: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags on an AWS IoT Things Graph resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
355 |
# File 'sig/client.rbs', line 355
def list_tags_for_resource: (
|
#search_entities(params = {}) ⇒ Types::SearchEntitiesResponse
Searches for entities of the specified type. You can search for entities in your namespace and the public namespace that you're tracking.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
368 |
# File 'sig/client.rbs', line 368
def search_entities: (
|
#search_flow_executions(params = {}) ⇒ Types::SearchFlowExecutionsResponse
Searches for AWS IoT Things Graph workflow execution instances.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
388 |
# File 'sig/client.rbs', line 388
def search_flow_executions: (
|
#search_flow_templates(params = {}) ⇒ Types::SearchFlowTemplatesResponse
Searches for summary information about workflows.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
404 |
# File 'sig/client.rbs', line 404
def search_flow_templates: (
|
#search_system_instances(params = {}) ⇒ Types::SearchSystemInstancesResponse
Searches for system instances in the user's account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
422 |
# File 'sig/client.rbs', line 422
def search_system_instances: (
|
#search_system_templates(params = {}) ⇒ Types::SearchSystemTemplatesResponse
Searches for summary information about systems in the user's account. You can filter by the ID of a workflow to return only systems that use the specified workflow.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
440 |
# File 'sig/client.rbs', line 440
def search_system_templates: (
|
#search_things(params = {}) ⇒ Types::SearchThingsResponse
Searches for things associated with the specified entity. You can search by both device and device model.
For example, if two different devices, camera1 and camera2, implement
the camera device model, the user can associate thing1 to camera1 and
thing2 to camera2. SearchThings(camera2) will return only thing2,
but SearchThings(camera) will return both thing1 and thing2.
This action searches for exact matches and doesn't perform partial text matching.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
458 |
# File 'sig/client.rbs', line 458
def search_things: (
|
#tag_resource(params = {}) ⇒ Struct
Creates a tag for the specified resource.
470 |
# File 'sig/client.rbs', line 470
def tag_resource: (
|
#undeploy_system_instance(params = {}) ⇒ Types::UndeploySystemInstanceResponse
Removes a system instance from its target (Cloud or Greengrass).
486 |
# File 'sig/client.rbs', line 486
def undeploy_system_instance: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag from the specified resource.
495 |
# File 'sig/client.rbs', line 495
def untag_resource: (
|
#update_flow_template(params = {}) ⇒ Types::UpdateFlowTemplateResponse
Updates the specified workflow. All deployed systems and system instances that use the workflow will see the changes in the flow when it is redeployed. If you don't want this behavior, copy the workflow (creating a new workflow with a different ID), and update the copy. The workflow can contain only entities in the specified namespace.
506 |
# File 'sig/client.rbs', line 506
def update_flow_template: (
|
#update_system_template(params = {}) ⇒ Types::UpdateSystemTemplateResponse
Updates the specified system. You don't need to run this action after updating a workflow. Any deployment that uses the system will see the changes in the system when it is redeployed.
521 |
# File 'sig/client.rbs', line 521
def update_system_template: (
|
#upload_entity_definitions(params = {}) ⇒ Types::UploadEntityDefinitionsResponse
Asynchronously uploads one or more entity definitions to the user's
namespace. The document parameter is required if
syncWithPublicNamespace and deleteExistingEntites are false. If
the syncWithPublicNamespace parameter is set to true, the user's
namespace will synchronize with the latest version of the public
namespace. If deprecateExistingEntities is set to true, all entities
in the latest version will be deleted before the new
DefinitionDocument is uploaded.
When a user uploads entity definitions for the first time, the service
creates a new namespace for the user. The new namespace tracks the
public namespace. Currently users can have only one namespace. The
namespace version increments whenever a user uploads entity
definitions that are backwards-incompatible and whenever a user sets
the syncWithPublicNamespace parameter or the
deprecateExistingEntities parameter to true.
The IDs for all of the entities should be in URN format. Each entity must be in the user's namespace. Users can't create entities in the public namespace, but entity definitions can refer to entities in the public namespace.
Valid entities are Device, DeviceModel, Service, Capability,
State, Action, Event, Property, Mapping, Enum.
536 |
# File 'sig/client.rbs', line 536
def upload_entity_definitions: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2056 2057 2058 |
# File 'lib/aws-sdk-iotthingsgraph/client.rb', line 2056 def waiter_names [] end |