Method: Aws::IoTThingsGraph::Client#describe_namespace

Defined in:
lib/aws-sdk-iotthingsgraph/client.rb

#describe_namespace(params = {}) ⇒ Types::DescribeNamespaceResponse

Gets the latest version of the user’s namespace and the public version that it is tracking.

Examples:

Request syntax with placeholder values


resp = client.describe_namespace({
  namespace_name: "NamespaceName",
})

Response structure


resp.namespace_arn #=> String
resp.namespace_name #=> String
resp.tracking_namespace_name #=> String
resp.tracking_namespace_version #=> Integer
resp.namespace_version #=> Integer

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :namespace_name (String)

    The name of the user’s namespace. Set this to aws to get the public namespace.

Returns:



952
953
954
955
# File 'lib/aws-sdk-iotthingsgraph/client.rb', line 952

def describe_namespace(params = {}, options = {})
  req = build_request(:describe_namespace, params)
  req.send_request(options)
end